@@ -1,6 +1,6 @@
 package Perinci;
 
-our $VERSION = '0.31'; # VERSION
+our $VERSION = '0.32'; # VERSION
 
 1;
 # ABSTRACT: Collection of Perl modules for Rinci and Riap
@@ -17,7 +17,7 @@ Perinci - Collection of Perl modules for Rinci and Riap
 
 =head1 VERSION
 
-version 0.31
+This document describes version 0.32 of Perinci (from Perl distribution Perinci), released on 2015-09-03.
 
 =head1 DESCRIPTION
 
@@ -86,11 +86,6 @@ See CPAN for more Perinci::* modules.
 
 To get started, read L<Perinci::Manual::Tutorial>.
 
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =head1 FAQ
 
 =head2 What does Perinci mean?
@@ -108,7 +103,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci>.
 
 =head1 BUGS
 
@@ -120,11 +115,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
